/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 32

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ;
typedef struct tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA;
typedef struct tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA;
typedef struct tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct tySequence__vvBerF0axaNtu9aMA2gnsrA tySequence__vvBerF0axaNtu9aMA2gnsrA;
typedef struct tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ;
typedef struct tySequence__ZQPym9bf1jM5qaSn7LUXMKA tySequence__ZQPym9bf1jM5qaSn7LUXMKA;
typedef struct tySequence__9c3OY0aBmSBgwdsnBAPf4Ag tySequence__9c3OY0aBmSBgwdsnBAPf4Ag;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw;
typedef struct tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ;
typedef struct tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tySequence__Jhh6ks9carRtwV9aOuM8yMNw tySequence__Jhh6ks9carRtwV9aOuM8yMNw;
typedef struct tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw tySequence__Bis5AbpONWcIRrPyPJS8Yw;
typedef struct tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg;
typedef struct tySequence__E8pi9b5QNahsURYzXMjh3qw tySequence__E8pi9b5QNahsURYzXMjh3qw;
typedef struct tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg;
typedef struct tySequence__XDpbjnuseLNZDGLBQ2Qzow tySequence__XDpbjnuseLNZDGLBQ2Qzow;
typedef struct tyObject_Table__cBohObSCAwRxvYFXQHv2wA tyObject_Table__cBohObSCAwRxvYFXQHv2wA;
typedef struct tySequence__QqvaCqCpEE1QmQZbcZLi5A tySequence__QqvaCqCpEE1QmQZbcZLi5A;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyObject_Env_patternsdotnim_matchNested___ZMveiFLFjcEa9b3tNmF1suw tyObject_Env_patternsdotnim_matchNested___ZMveiFLFjcEa9b3tNmF1suw;
typedef struct tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg;
typedef struct tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q;
typedef struct tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA;
typedef struct tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w;
typedef struct tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA;
typedef struct tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg;
typedef struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ tyTuple__NAaJgGVgNmlGoqmiWxdOHQ;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tyTuple__VbApVidEWCFLq9a29bPtaS7A tyTuple__VbApVidEWCFLq9a29bPtaS7A;
typedef struct tySequence__k7EQb9bN3Uhl608xoPGMRJA tySequence__k7EQb9bN3Uhl608xoPGMRJA;
typedef struct tyTuple__toqrUPSdp8zSxOdlxMJj9cA tyTuple__toqrUPSdp8zSxOdlxMJj9cA;
typedef struct tyTuple__EbsafWGli8bW2GRJQ9apsjA tyTuple__EbsafWGli8bW2GRJQ9apsjA;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
struct tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* mapping;
NI formals;
tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c;
NIM_BOOL subMatch;
NIM_BOOL mappingIsFull;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw {
  RootObj Sup;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__aaEwD7wUZoIxDUprFEbfMQ[38];
struct tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ {
NI counter;
tySequence__ZQPym9bf1jM5qaSn7LUXMKA* data;
};
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__q9caIJqxIEVMlKzDKc7PN3A) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* expectedType);
typedef NU32 tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__Kiet6YwcQwPvcQYHHEqqqQ) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* expectedType);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__PSlVV9bxpH9avY5YrjCD5uqA) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__8k9afYvvfaH1tjWAwlISb0A) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, void* ClE_0);
void* ClE_0;
} tyProc__9bnYcX9avusKBraL3FJXBwJw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__uojbiMfaKLMuGW9bbomtTBg) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
typedef NU32 tySet_tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__bqRyngJC8bSPcUqqn9bn73w) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nOrig, tySet_tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw filter, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags);
typedef N_NIMCALL_PTR(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, tyProc__F6LocU8y66ng5Ra4XoVWJA) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* prev);
typedef struct {
N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, void* ClE_0);
void* ClE_0;
} tyProc__Nc9aAsBDTkr61wP9a9cnds8Og;
typedef struct {
N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fn, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, void* ClE_0);
void* ClE_0;
} tyProc__z8FaSv6eEIc72FZ9c9cBcaGg;
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw {
NI counter;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* data;
};
typedef NU8 tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ;
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__9aa59awckKpa9areOQSBOwSeQ) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* dc, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ op, NI col);
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
struct tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ {
tySequence__Bis5AbpONWcIRrPyPJS8Yw* data;
NI counter;
};
struct tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg {
tySequence__E8pi9b5QNahsURYzXMjh3qw* data;
NI counter;
};
struct tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg {
tySequence__XDpbjnuseLNZDGLBQ2Qzow* data;
NI counter;
};
struct tyObject_Table__cBohObSCAwRxvYFXQHv2wA {
tySequence__QqvaCqCpEE1QmQZbcZLi5A* data;
NI counter;
};
struct tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw {
  tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw Sup;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* enforceVoidContext;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* voidType;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* currentScope;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* moduleScope;
tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA* imports;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* topLevelScope;
tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA* p;
tyArray__aaEwD7wUZoIxDUprFEbfMQ intTypeCache;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* nilTypeCache;
tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw* matchedConcept;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* friendModules;
NI instCounter;
NI* templInstCounter;
NI inGenericContext;
NI inStaticContext;
NI inUnrolledContext;
NI compilesContextId;
NI compilesContextIdGenerator;
NI inGenericInst;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* converters;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* patterns;
tySequence__vvBerF0axaNtu9aMA2gnsrA* optionStack;
tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ symMapping;
tySequence__9c3OY0aBmSBgwdsnBAPf4Ag* libs;
tyProc__q9caIJqxIEVMlKzDKc7PN3A semConstExpr;
tyProc__Kiet6YwcQwPvcQYHHEqqqQ semExpr;
tyProc__PSlVV9bxpH9avY5YrjCD5uqA semTryExpr;
tyProc__q9caIJqxIEVMlKzDKc7PN3A semTryConstExpr;
tyProc__8k9afYvvfaH1tjWAwlISb0A computeRequiresInit;
tyProc__9bnYcX9avusKBraL3FJXBwJw hasUnresolvedArgs;
tyProc__PSlVV9bxpH9avY5YrjCD5uqA semOperand;
tyProc__uojbiMfaKLMuGW9bbomtTBg semConstBoolExpr;
tyProc__bqRyngJC8bSPcUqqn9bn73w semOverloadedCall;
tyProc__F6LocU8y66ng5Ra4XoVWJA semTypeNode;
tyProc__Nc9aAsBDTkr61wP9a9cnds8Og semInferredLambda;
tyProc__z8FaSv6eEIc72FZ9c9cBcaGg semGenerateInstance;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw includedFiles;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw pureEnumFields;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw userPragmas;
tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ* evalContext;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw unknownIdents;
tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ* generics;
NI topStmts;
NI lastGenericIdx;
NI hloLoopDetector;
NI inParallelStmt;
tyProc__9aa59awckKpa9areOQSBOwSeQ instTypeBoundOp;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* selfName;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw signatures;
NimStringDesc* recursiveDep;
NIM_BOOL suggestionsMade;
NIM_BOOL isAmbiguous;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
NI inTypeContext;
NI inConceptDecl;
tySequence__Jhh6ks9carRtwV9aOuM8yMNw* unusedImports;
tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ exportIndirections;
tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg importModuleMap;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastTLineInfo;
tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg sideEffects;
NI inUncheckedAssignSection;
tyObject_Table__cBohObSCAwRxvYFXQHv2wA importModuleLookup;
};
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
typedef NU8 tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg {
NI id;
NimStringDesc* s;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* next;
NI h;
};
typedef NU8 tySet_tyEnum_TTypeCmpFlag__IRq9bqtrf9ctEUyeRMyvWy4Q;
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
struct tyObject_Env_patternsdotnim_matchNested___ZMveiFLFjcEa9b3tNmF1suw {
  RootObj Sup;
NI colonstate_;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p1;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* op, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arglist, NIM_BOOL rpn, void* ClE_0);
void* ClE_0;
} tyProc__JUFpjAFYH6dJQRsbQfQfmA;
typedef N_CLOSURE_PTR(NIM_BOOL, TM__boskDBJ4Cp44KknuaESeng_7) (tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* op, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arglist, NIM_BOOL rpn);
typedef N_CLOSURE_PTR(NIM_BOOL, TM__boskDBJ4Cp44KknuaESeng_8) (tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* op, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arglist, NIM_BOOL rpn);
typedef N_CLOSURE_PTR(NIM_BOOL, TM__boskDBJ4Cp44KknuaESeng_9) (tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* op, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arglist, NIM_BOOL rpn);
typedef NU8 tyEnum_TAliasRequest__7zQvSP68l08u9cyWRw1zgvg;
typedef NU8 tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA;
typedef NU8 tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ;
struct tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m;
tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ mode;
union{
struct {tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw imported;
} _mode_2;
struct {tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw exceptSet;
} _mode_3;
};
};
struct tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA {
tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key;
RootObj* val;
};
struct tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* genericSym;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field0;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field1;
};
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
NI Field0;
NI Field1;
};
struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ {
NI Field0;
tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ Field1;
};
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
struct tyTuple__toqrUPSdp8zSxOdlxMJj9cA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
struct tyTuple__VbApVidEWCFLq9a29bPtaS7A {
NI Field0;
NI Field1;
tySequence__k7EQb9bN3Uhl608xoPGMRJA* Field2;
};
struct tyTuple__EbsafWGli8bW2GRJQ9apsjA {
NI Field0;
NI Field1;
tySequence__qwqHTkRvwhrRyENtudHQ7g* Field2;
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA {
  TGenericSeq Sup;
  tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg data[SEQ_DECL_SIZE];
};
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
struct tySequence__vvBerF0axaNtu9aMA2gnsrA {
  TGenericSeq Sup;
  tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q* data[SEQ_DECL_SIZE];
};
struct tySequence__ZQPym9bf1jM5qaSn7LUXMKA {
  TGenericSeq Sup;
  tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA data[SEQ_DECL_SIZE];
};
struct tySequence__9c3OY0aBmSBgwdsnBAPf4Ag {
  TGenericSeq Sup;
  tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ {
  TGenericSeq Sup;
  tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w data[SEQ_DECL_SIZE];
};
struct tySequence__Jhh6ks9carRtwV9aOuM8yMNw {
  TGenericSeq Sup;
  tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg data[SEQ_DECL_SIZE];
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw {
  TGenericSeq Sup;
  tyTuple__NAaJgGVgNmlGoqmiWxdOHQ data[SEQ_DECL_SIZE];
};
struct tySequence__E8pi9b5QNahsURYzXMjh3qw {
  TGenericSeq Sup;
  tyTuple__47w2DboNEPf69aPgubZdd7Q data[SEQ_DECL_SIZE];
};
struct tySequence__k7EQb9bN3Uhl608xoPGMRJA {
  TGenericSeq Sup;
  tyTuple__toqrUPSdp8zSxOdlxMJj9cA data[SEQ_DECL_SIZE];
};
struct tySequence__XDpbjnuseLNZDGLBQ2Qzow {
  TGenericSeq Sup;
  tyTuple__VbApVidEWCFLq9a29bPtaS7A data[SEQ_DECL_SIZE];
};
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  TGenericSeq Sup;
  NI data[SEQ_DECL_SIZE];
};
struct tySequence__QqvaCqCpEE1QmQZbcZLi5A {
  TGenericSeq Sup;
  tyTuple__EbsafWGli8bW2GRJQ9apsjA data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
static N_INLINE(NI, len__ast_3990)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, matchStmtList__patterns_432)(tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, flattenStmts__trees_355)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, matchRange__patterns_437)(tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI i);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, matches__patterns_29)(tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, skipHidden__types_3671)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NIM_BOOL, isPatternParam__patterns_114)(tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, bindOrCheck__patterns_144)(tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* param, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, getLazy__patterns_17)(tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameTrees__patterns_48)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
static N_INLINE(NIM_BOOL, sameKinds__patterns_36)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw, canonKind__patterns_33)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameTypeOrNil__types_1904)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* b, tySet_tyEnum_TTypeCmpFlag__IRq9bqtrf9ctEUyeRMyvWy4Q flags);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, checkTypes__patterns_98)(tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, matchNodeKinds__parampatterns_505)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, argtypeMatches__sigmatch_4322)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, NIM_BOOL fromHlo);
N_LIB_PRIVATE N_NIMCALL(void, putLazy__patterns_21)(tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void*, newSeq)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5258)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, inSymChoice__patterns_72)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* sc, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, matchChoice__patterns_130)(tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, matchNested__patterns_176)(tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL rpn);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tyRef__9aLIDkd3W4BIOb9auvDSYiog)(void* p, NI op);
N_LIB_PRIVATE N_NOINLINE(void*, newObj)(TNimType* typ, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeI__ast_3320)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_CLOSURE(NIM_BOOL, matchStarAux__patterns_182)(tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* op, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arglist, NIM_BOOL rpn, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_4798)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* son);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__systemZassertions_56)(NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(void, gather__patterns_158)(tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* param, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeI__ast_3324)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NI children);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, lastSon__ast_4833)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, extractRange__trees_362)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw k, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI a, NI b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newSymNode__ast_3707)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, aliasAnalysisRequested__patterns_495)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* params);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAliasRequest__7zQvSP68l08u9cyWRw1zgvg, whichAlias__parampatterns_48)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* p);
N_LIB_PRIVATE N_NIMCALL(void, addToArgList__patterns_516)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA, isPartOf__aliases_129)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
N_LIB_PRIVATE N_NIMCALL(void, markUsed__sigmatch_85)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
extern TNimType NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_;
STRING_LITERAL(TM__boskDBJ4Cp44KknuaESeng_2, "|", 1);
STRING_LITERAL(TM__boskDBJ4Cp44KknuaESeng_3, "*", 1);
STRING_LITERAL(TM__boskDBJ4Cp44KknuaESeng_4, "**", 2);
STRING_LITERAL(TM__boskDBJ4Cp44KknuaESeng_5, "~", 1);
extern TNimType NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_;
N_LIB_PRIVATE TNimType NTIobject__ZMveiFLFjcEa9b3tNmF1suw_;
extern TNimType NTIint__xHTZrq9aYs6boc9bCba0JbpQ_;
extern TNimType NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_;
N_LIB_PRIVATE TNimType NTIrefobject__9aLIDkd3W4BIOb9auvDSYiog_;
STRING_LITERAL(TM__boskDBJ4Cp44KknuaESeng_10, "patterns.nim(155, 19) `false` invalid pattern", 45);
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5211;
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(NI, len__ast_3990)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n).sons ? (*n).sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(NIM_BOOL, isPatternParam__patterns_114)(tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*p).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
	if (!(T2_)) goto LA3_;
	T2_ = ((*(*p)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = ((*(*p)._kind_4.sym).owner == (*c).owner);
	LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, getLazy__patterns_17)(tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	{
		if (!(*c).mappingIsFull) goto LA3_;
		result = (*c).mapping->data[(*sym).position];
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw, canonKind__patterns_33)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw result;
	result = (tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw)0;
	result = (*n).kind;
	switch (result) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
	{
		result = ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22):
	{
		result = ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 74):
	{
		result = ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 73);
	}
	break;
	default:
	{
	}
	break;
	}
	return result;
}
static N_INLINE(NIM_BOOL, sameKinds__patterns_36)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw T3_;
	tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw T4_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*a).kind == (*b).kind);
	if (T1_) goto LA2_;
	T3_ = (tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw)0;
	T3_ = canonKind__patterns_33(a);
	T4_ = (tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw)0;
	T4_ = canonKind__patterns_33(b);
	T1_ = (T3_ == T4_);
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameTrees__patterns_48)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = sameKinds__patterns_36(a, b);
		if (!T3_) goto LA4_;
		switch ((*a).kind) {
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
		{
			result = ((*a)._kind_4.sym == (*b)._kind_4.sym);
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
		{
			result = ((*(*a)._kind_5.ident).id == (*(*b)._kind_5.ident).id);
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 10):
		{
			result = ((*a)._kind_1.intVal == (*b)._kind_1.intVal);
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 16) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 18):
		{
			result = ((*a)._kind_2.floatVal == (*b)._kind_2.floatVal);
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22):
		{
			result = eqStrings((*a)._kind_3.strVal, (*b)._kind_3.strVal);
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1):
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
		{
			result = NIM_TRUE;
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 4):
		{
			result = sameTypeOrNil__types_1904((*a).typ, (*b).typ, 0);
		}
		break;
		default:
		{
			{
				NI T16_;
				NI T17_;
				T16_ = (NI)0;
				T16_ = len__ast_3155(a);
				T17_ = (NI)0;
				T17_ = len__ast_3155(b);
				if (!(T16_ == T17_)) goto LA18_;
				{
					NI i;
					NI colontmp_;
					NI i_2;
					i = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = len__ast_3155(a);
					i_2 = ((NI) 0);
					{
						while (1) {
							if (!(i_2 < colontmp_)) goto LA22;
							i = i_2;
							{
								NIM_BOOL T25_;
								T25_ = (NIM_BOOL)0;
								T25_ = sameTrees__patterns_48((*a)._kind_6.sons->data[i], (*b)._kind_6.sons->data[i]);
								if (!!(T25_)) goto LA26_;
								goto BeforeRet_;
							}
							LA26_: ;
							i_2 += ((NI) 1);
						} LA22: ;
					}
				}
				result = NIM_TRUE;
			}
			LA18_: ;
		}
		break;
		}
	}
	LA4_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, checkTypes__patterns_98)(tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!!(((*p).constraint == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA3_;
		result = matchNodeKinds__parampatterns_505((*p).constraint, n);
		{
			if (!!(result)) goto LA7_;
			goto BeforeRet_;
		}
		LA7_: ;
	}
	LA3_: ;
	{
		if (!((*n).typ == 0)) goto LA11_;
		result = ((*(*p).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 63) || (*(*p).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 7));
	}
	goto LA9_;
	LA11_: ;
	{
		result = argtypeMatches__sigmatch_4322((*c).c, (*p).typ, (*n).typ, NIM_TRUE);
	}
	LA9_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5258((&gch__system_5211.zct), c);
}
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5307(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5264(src);
		incRef__system_5302(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5264((*dest));
		decRef__system_5309(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(void, putLazy__patterns_21)(tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		if (!!((*c).mappingIsFull)) goto LA3_;
		unsureAsgnRef((void**) (&(*c).mapping), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) newSeq((&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) ((*c).formals))));
		(*c).mappingIsFull = NIM_TRUE;
	}
	LA3_: ;
	asgnRef((void**) (&(*c).mapping->data[(*sym).position]), n);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, bindOrCheck__patterns_144)(tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* param, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pp;
	result = (NIM_BOOL)0;
	pp = getLazy__patterns_17(c, param);
	{
		if (!!((pp == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA3_;
		result = sameTrees__patterns_48(pp, n);
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T6_;
		T6_ = (NIM_BOOL)0;
		T6_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152));
		if (T6_) goto LA7_;
		T6_ = checkTypes__patterns_98(c, param, n);
		LA7_: ;
		if (!T6_) goto LA8_;
		putLazy__patterns_21(c, param, n);
		result = NIM_TRUE;
	}
	goto LA1_;
	LA8_: ;
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, inSymChoice__patterns_72)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* sc, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!((*sc).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 56))) goto LA3_;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(sc);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA7;
					i = i_2;
					{
						if (!((*(*sc)._kind_6.sons->data[i])._kind_4.sym == (*x)._kind_4.sym)) goto LA10_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA10_: ;
					i_2 += ((NI) 1);
				} LA7: ;
			}
		}
	}
	goto LA1_;
	LA3_: ;
	{
		if (!((*sc).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 57))) goto LA13_;
		result = ((*(*(*(*sc)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).id == (*(*(*x)._kind_4.sym).name).id);
	}
	goto LA1_;
	LA13_: ;
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, matchChoice__patterns_130)(tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(p);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					NIM_BOOL T6_;
					T6_ = (NIM_BOOL)0;
					T6_ = matches__patterns_29(c, (*p)._kind_6.sons->data[i], n);
					if (!T6_) goto LA7_;
					result = NIM_TRUE;
					goto BeforeRet_;
				}
				LA7_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_NIMCALL(void, Marker_tyRef__9aLIDkd3W4BIOb9auvDSYiog)(void* p, NI op) {
	tyObject_Env_patternsdotnim_matchNested___ZMveiFLFjcEa9b3tNmF1suw* a;
	a = (tyObject_Env_patternsdotnim_matchNested___ZMveiFLFjcEa9b3tNmF1suw*)p;
	nimGCvisit((void*)(*a).p1, op);
}
N_LIB_PRIVATE N_CLOSURE(NIM_BOOL, matchStarAux__patterns_182)(tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* op, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arglist, NIM_BOOL rpn, void* ClE_0) {
	NIM_BOOL result;
	tyObject_Env_patternsdotnim_matchNested___ZMveiFLFjcEa9b3tNmF1suw* colonenvP_;
{	result = (NIM_BOOL)0;
	colonenvP_ = (tyObject_Env_patternsdotnim_matchNested___ZMveiFLFjcEa9b3tNmF1suw*) ClE_0;
	result = NIM_TRUE;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32));
		if (!(T3_)) goto LA4_;
		T3_ = matches__patterns_29(c, (*op)._kind_6.sons->data[((NI) 1)], (*n)._kind_6.sons->data[((NI) 0)]);
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 1);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA9;
					i = i_2;
					{
						tyProc__JUFpjAFYH6dJQRsbQfQfmA T12_;
						NIM_BOOL T13_;
						nimZeroMem((void*)(&T12_), sizeof(tyProc__JUFpjAFYH6dJQRsbQfQfmA));
						T12_.ClP_0 = matchStarAux__patterns_182; T12_.ClE_0 = colonenvP_;
						T13_ = (NIM_BOOL)0;
						T13_ = T12_.ClE_0? T12_.ClP_0(c, op, (*n)._kind_6.sons->data[i], arglist, rpn, T12_.ClE_0):((TM__boskDBJ4Cp44KknuaESeng_7)(T12_.ClP_0))(c, op, (*n)._kind_6.sons->data[i], arglist, rpn);
						if (!!(T13_)) goto LA14_;
						result = NIM_FALSE;
						goto BeforeRet_;
					}
					LA14_: ;
					i_2 += ((NI) 1);
				} LA9: ;
			}
		}
		{
			if (!rpn) goto LA18_;
			add__ast_4798(arglist, (*n)._kind_6.sons->data[((NI) 0)]);
		}
		LA18_: ;
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T21_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n_2;
		T21_ = (NIM_BOOL)0;
		T21_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58));
		if (!(T21_)) goto LA22_;
		T21_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41));
		LA22_: ;
		if (!T21_) goto LA23_;
		n_2 = (*n)._kind_6.sons->data[((NI) 1)];
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3155(n_2);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA27;
					i_3 = i_4;
					{
						tyProc__JUFpjAFYH6dJQRsbQfQfmA T30_;
						NIM_BOOL T31_;
						nimZeroMem((void*)(&T30_), sizeof(tyProc__JUFpjAFYH6dJQRsbQfQfmA));
						T30_.ClP_0 = matchStarAux__patterns_182; T30_.ClE_0 = colonenvP_;
						T31_ = (NIM_BOOL)0;
						T31_ = T30_.ClE_0? T30_.ClP_0(c, op, (*n_2)._kind_6.sons->data[i_3], arglist, rpn, T30_.ClE_0):((TM__boskDBJ4Cp44KknuaESeng_8)(T30_.ClP_0))(c, op, (*n_2)._kind_6.sons->data[i_3], arglist, rpn);
						if (!!(T31_)) goto LA32_;
						result = NIM_FALSE;
						goto BeforeRet_;
					}
					LA32_: ;
					i_4 += ((NI) 1);
				} LA27: ;
			}
		}
	}
	goto LA1_;
	LA23_: ;
	{
		NIM_BOOL T35_;
		T35_ = (NIM_BOOL)0;
		T35_ = checkTypes__patterns_98(c, (*(*(*colonenvP_).p1)._kind_6.sons->data[((NI) 2)])._kind_4.sym, n);
		if (!T35_) goto LA36_;
		add__ast_4798(arglist, n);
	}
	goto LA1_;
	LA36_: ;
	{
		result = NIM_FALSE;
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, matchNested__patterns_176)(tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL rpn) {
	NIM_BOOL result;
	tyObject_Env_patternsdotnim_matchNested___ZMveiFLFjcEa9b3tNmF1suw* colonenv_;
{	result = (NIM_BOOL)0;
	colonenv_ = NIM_NIL;
	colonenv_ = (tyObject_Env_patternsdotnim_matchNested___ZMveiFLFjcEa9b3tNmF1suw*) newObj((&NTIrefobject__9aLIDkd3W4BIOb9auvDSYiog_), sizeof(tyObject_Env_patternsdotnim_matchNested___ZMveiFLFjcEa9b3tNmF1suw));
	(*colonenv_).Sup.m_type = (&NTIobject__ZMveiFLFjcEa9b3tNmF1suw_);
	asgnRef((void**) (&(*colonenv_).p1), p);
	{
		if (!!(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32)))) goto LA3_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NIM_BOOL T7_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arglist;
		T7_ = (NIM_BOOL)0;
		T7_ = matches__patterns_29(c, (*(*colonenv_).p1)._kind_6.sons->data[((NI) 1)], (*n)._kind_6.sons->data[((NI) 0)]);
		if (!T7_) goto LA8_;
		arglist = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152), (*n).info);
		{
			tyProc__JUFpjAFYH6dJQRsbQfQfmA T12_;
			NIM_BOOL T13_;
			nimZeroMem((void*)(&T12_), sizeof(tyProc__JUFpjAFYH6dJQRsbQfQfmA));
			T12_.ClP_0 = matchStarAux__patterns_182; T12_.ClE_0 = colonenv_;
			T13_ = (NIM_BOOL)0;
			T13_ = T12_.ClE_0? T12_.ClP_0(c, (*colonenv_).p1, n, arglist, rpn, T12_.ClE_0):((TM__boskDBJ4Cp44KknuaESeng_9)(T12_.ClP_0))(c, (*colonenv_).p1, n, arglist, rpn);
			if (!T13_) goto LA14_;
			result = bindOrCheck__patterns_144(c, (*(*(*colonenv_).p1)._kind_6.sons->data[((NI) 2)])._kind_4.sym, arglist);
		}
		LA14_: ;
	}
	LA8_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, gather__patterns_158)(tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* param, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pp;
	pp = getLazy__patterns_17(c, param);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !((pp == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((*pp).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152));
		LA4_: ;
		if (!T3_) goto LA5_;
		add__ast_4798(pp, n);
	}
	goto LA1_;
	LA5_: ;
	{
		pp = newNodeI__ast_3324(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152), (*n).info, ((NI) 1));
		asgnRef((void**) (&(*pp)._kind_6.sons->data[((NI) 0)]), n);
		putLazy__patterns_21(c, param, pp);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, matches__patterns_29)(tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n_2;
{	result = (NIM_BOOL)0;
	n_2 = skipHidden__types_3671(n);
	{
		if (!(((*n_2).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg) 6))&31U)))!=0)) goto LA3_;
		result = NIM_FALSE;
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T6_;
		T6_ = (NIM_BOOL)0;
		T6_ = isPatternParam__patterns_114(c, p);
		if (!T6_) goto LA7_;
		result = bindOrCheck__patterns_144(c, (*p)._kind_4.sym, n_2);
	}
	goto LA1_;
	LA7_: ;
	{
		NIM_BOOL T10_;
		T10_ = (NIM_BOOL)0;
		T10_ = ((*n_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		if (!(T10_)) goto LA11_;
		T10_ = ((*p).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2));
		LA11_: ;
		if (!T10_) goto LA12_;
		result = ((*(*p)._kind_5.ident).id == (*(*(*n_2)._kind_4.sym).name).id);
	}
	goto LA1_;
	LA12_: ;
	{
		NIM_BOOL T15_;
		T15_ = (NIM_BOOL)0;
		T15_ = ((*n_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		if (!(T15_)) goto LA16_;
		T15_ = inSymChoice__patterns_72(p, n_2);
		LA16_: ;
		if (!T15_) goto LA17_;
		result = NIM_TRUE;
	}
	goto LA1_;
	LA17_: ;
	{
		NIM_BOOL T20_;
		T20_ = (NIM_BOOL)0;
		T20_ = ((*n_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		if (!(T20_)) goto LA21_;
		T20_ = ((*(*n_2)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 10));
		LA21_: ;
		if (!T20_) goto LA22_;
		{
			if (!((*p).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA26_;
			result = ((*p)._kind_4.sym == (*n_2)._kind_4.sym);
		}
		goto LA24_;
		LA26_: ;
		{
			NIM_BOOL T29_;
			T29_ = (NIM_BOOL)0;
			T29_ = matches__patterns_29(c, p, (*(*n_2)._kind_4.sym).ast);
			if (!T29_) goto LA30_;
			result = NIM_TRUE;
		}
		goto LA24_;
		LA30_: ;
		LA24_: ;
	}
	goto LA1_;
	LA22_: ;
	{
		NimStringDesc* opr;
		if (!((*p).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 153))) goto LA33_;
		opr = (*(*(*p)._kind_6.sons->data[((NI) 0)])._kind_5.ident).s;
		if (eqStrings(opr, ((NimStringDesc*) &TM__boskDBJ4Cp44KknuaESeng_2))) goto LA35_;
		if (eqStrings(opr, ((NimStringDesc*) &TM__boskDBJ4Cp44KknuaESeng_3))) goto LA36_;
		if (eqStrings(opr, ((NimStringDesc*) &TM__boskDBJ4Cp44KknuaESeng_4))) goto LA37_;
		if (eqStrings(opr, ((NimStringDesc*) &TM__boskDBJ4Cp44KknuaESeng_5))) goto LA38_;
		goto LA39_;
		LA35_: ;
		{
			result = matchChoice__patterns_130(c, p, n_2);
		}
		goto LA40_;
		LA36_: ;
		{
			result = matchNested__patterns_176(c, p, n_2, NIM_FALSE);
		}
		goto LA40_;
		LA37_: ;
		{
			result = matchNested__patterns_176(c, p, n_2, NIM_TRUE);
		}
		goto LA40_;
		LA38_: ;
		{
			NIM_BOOL T45_;
			T45_ = (NIM_BOOL)0;
			T45_ = matches__patterns_29(c, (*p)._kind_6.sons->data[((NI) 1)], n_2);
			result = !(T45_);
		}
		goto LA40_;
		LA39_: ;
		{
			{
				if (!NIM_TRUE) goto LA49_;
				failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__boskDBJ4Cp44KknuaESeng_10));
			}
			LA49_: ;
		}
		LA40_: ;
	}
	goto LA1_;
	LA33_: ;
	{
		if (!((*p).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 40))) goto LA52_;
		{
			if (!((*(*p)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30))) goto LA56_;
			{
				NIM_BOOL T60_;
				T60_ = (NIM_BOOL)0;
				T60_ = matches__patterns_29(c, (*p)._kind_6.sons->data[((NI) 0)], n_2);
				if (!T60_) goto LA61_;
				gather__patterns_158(c, (*(*(*p)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 1)])._kind_4.sym, n_2);
				result = NIM_TRUE;
			}
			LA61_: ;
		}
		goto LA54_;
		LA56_: ;
		{
			{
				NIM_BOOL T66_;
				T66_ = (NIM_BOOL)0;
				T66_ = matches__patterns_29(c, (*p)._kind_6.sons->data[((NI) 0)], n_2);
				if (!T66_) goto LA67_;
				result = bindOrCheck__patterns_144(c, (*(*p)._kind_6.sons->data[((NI) 1)])._kind_4.sym, n_2);
			}
			LA67_: ;
		}
		LA54_: ;
	}
	goto LA1_;
	LA52_: ;
	{
		NIM_BOOL T70_;
		T70_ = (NIM_BOOL)0;
		T70_ = sameKinds__patterns_36(p, n_2);
		if (!T70_) goto LA71_;
		switch ((*p).kind) {
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
		{
			result = ((*p)._kind_4.sym == (*n_2)._kind_4.sym);
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
		{
			result = ((*(*p)._kind_5.ident).id == (*(*n_2)._kind_5.ident).id);
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 10):
		{
			result = ((*p)._kind_1.intVal == (*n_2)._kind_1.intVal);
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 16) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 18):
		{
			result = ((*p)._kind_2.floatVal == (*n_2)._kind_2.floatVal);
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22):
		{
			result = eqStrings((*p)._kind_3.strVal, (*n_2)._kind_3.strVal);
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1):
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 4):
		{
			result = NIM_TRUE;
		}
		break;
		default:
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* v;
			v = lastSon__ast_4833(p);
			{
				NIM_BOOL T82_;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arglist;
				T82_ = (NIM_BOOL)0;
				T82_ = isPatternParam__patterns_114(c, v);
				if (!(T82_)) goto LA83_;
				T82_ = ((*(*(*v)._kind_4.sym).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48));
				LA83_: ;
				if (!T82_) goto LA84_;
				arglist = NIM_NIL;
				{
					NI T88_;
					NI T89_;
					T88_ = (NI)0;
					T88_ = len__ast_3155(p);
					T89_ = (NI)0;
					T89_ = len__ast_3155(n_2);
					if (!(T88_ <= T89_)) goto LA90_;
					{
						NI i;
						NI colontmp_;
						NI T93_;
						NI i_2;
						i = (NI)0;
						colontmp_ = (NI)0;
						T93_ = (NI)0;
						T93_ = len__ast_3155(p);
						colontmp_ = (NI)(T93_ - ((NI) 1));
						i_2 = ((NI) 0);
						{
							while (1) {
								if (!(i_2 < colontmp_)) goto LA95;
								i = i_2;
								{
									NIM_BOOL T98_;
									T98_ = (NIM_BOOL)0;
									T98_ = matches__patterns_29(c, (*p)._kind_6.sons->data[i], (*n_2)._kind_6.sons->data[i]);
									if (!!(T98_)) goto LA99_;
									goto BeforeRet_;
								}
								LA99_: ;
								i_2 += ((NI) 1);
							} LA95: ;
						}
					}
					{
						NIM_BOOL T103_;
						NIM_BOOL T104_;
						NI T105_;
						NI T106_;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T108_;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T110_;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n_3;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T113_;
						NI T114_;
						T103_ = (NIM_BOOL)0;
						T104_ = (NIM_BOOL)0;
						T105_ = (NI)0;
						T105_ = len__ast_3155(p);
						T106_ = (NI)0;
						T106_ = len__ast_3155(n_2);
						T104_ = (T105_ == T106_);
						if (!(T104_)) goto LA107_;
						T108_ = NIM_NIL;
						T108_ = lastSon__ast_4833(n_2);
						T104_ = ((*T108_).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58));
						LA107_: ;
						T103_ = T104_;
						if (!(T103_)) goto LA109_;
						T110_ = NIM_NIL;
						T110_ = lastSon__ast_4833(n_2);
						T103_ = ((*(*T110_)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41));
						LA109_: ;
						if (!T103_) goto LA111_;
						T113_ = NIM_NIL;
						T113_ = lastSon__ast_4833(n_2);
						n_3 = (*T113_)._kind_6.sons->data[((NI) 1)];
						T114_ = (NI)0;
						T114_ = len__ast_3155(n_3);
						arglist = newNodeI__ast_3324(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152), (*n_3).info, T114_);
						{
							NI i_3;
							NI colontmp__2;
							NI i_4;
							i_3 = (NI)0;
							colontmp__2 = (NI)0;
							colontmp__2 = len__ast_3155(n_3);
							i_4 = ((NI) 0);
							{
								while (1) {
									if (!(i_4 < colontmp__2)) goto LA117;
									i_3 = i_4;
									asgnRef((void**) (&(*arglist)._kind_6.sons->data[i_3]), (*n_3)._kind_6.sons->data[i_3]);
									i_4 += ((NI) 1);
								} LA117: ;
							}
						}
					}
					goto LA101_;
					LA111_: ;
					{
						NI T119_;
						NI T120_;
						T119_ = (NI)0;
						T119_ = len__ast_3155(n_2);
						T120_ = (NI)0;
						T120_ = len__ast_3155(p);
						arglist = newNodeI__ast_3324(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152), (*n_2).info, (NI)((NI)(T119_ - T120_) + ((NI) 1)));
						{
							NI i_5;
							NI colontmp__3;
							NI T122_;
							NI T123_;
							NI res;
							i_5 = (NI)0;
							colontmp__3 = (NI)0;
							T122_ = (NI)0;
							T122_ = len__ast_3155(n_2);
							T123_ = (NI)0;
							T123_ = len__ast_3155(p);
							colontmp__3 = (NI)(T122_ - T123_);
							res = ((NI) 0);
							{
								while (1) {
									NI T126_;
									if (!(res <= colontmp__3)) goto LA125;
									i_5 = res;
									T126_ = (NI)0;
									T126_ = len__ast_3155(p);
									asgnRef((void**) (&(*arglist)._kind_6.sons->data[i_5]), (*n_2)._kind_6.sons->data[(NI)((NI)(i_5 + T126_) - ((NI) 1))]);
									res += ((NI) 1);
								} LA125: ;
							}
						}
					}
					LA101_: ;
					result = bindOrCheck__patterns_144(c, (*v)._kind_4.sym, arglist);
					goto BeforeRet_;
				}
				goto LA86_;
				LA90_: ;
				{
					NI T128_;
					NI T129_;
					T128_ = (NI)0;
					T128_ = len__ast_3155(p);
					T129_ = (NI)0;
					T129_ = len__ast_3155(n_2);
					if (!((NI)(T128_ - ((NI) 1)) == T129_)) goto LA130_;
					{
						NI i_6;
						NI colontmp__4;
						NI T133_;
						NI i_7;
						i_6 = (NI)0;
						colontmp__4 = (NI)0;
						T133_ = (NI)0;
						T133_ = len__ast_3155(p);
						colontmp__4 = (NI)(T133_ - ((NI) 1));
						i_7 = ((NI) 0);
						{
							while (1) {
								if (!(i_7 < colontmp__4)) goto LA135;
								i_6 = i_7;
								{
									NIM_BOOL T138_;
									T138_ = (NIM_BOOL)0;
									T138_ = matches__patterns_29(c, (*p)._kind_6.sons->data[i_6], (*n_2)._kind_6.sons->data[i_6]);
									if (!!(T138_)) goto LA139_;
									goto BeforeRet_;
								}
								LA139_: ;
								i_7 += ((NI) 1);
							} LA135: ;
						}
					}
					arglist = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152), (*n_2).info);
					result = bindOrCheck__patterns_144(c, (*v)._kind_4.sym, arglist);
					goto BeforeRet_;
				}
				goto LA86_;
				LA130_: ;
				LA86_: ;
			}
			LA84_: ;
			{
				NI T143_;
				NI T144_;
				T143_ = (NI)0;
				T143_ = len__ast_3155(p);
				T144_ = (NI)0;
				T144_ = len__ast_3155(n_2);
				if (!(T143_ == T144_)) goto LA145_;
				{
					NI i_8;
					NI colontmp__5;
					NI i_9;
					i_8 = (NI)0;
					colontmp__5 = (NI)0;
					colontmp__5 = len__ast_3155(p);
					i_9 = ((NI) 0);
					{
						while (1) {
							if (!(i_9 < colontmp__5)) goto LA149;
							i_8 = i_9;
							{
								NIM_BOOL T152_;
								T152_ = (NIM_BOOL)0;
								T152_ = matches__patterns_29(c, (*p)._kind_6.sons->data[i_8], (*n_2)._kind_6.sons->data[i_8]);
								if (!!(T152_)) goto LA153_;
								goto BeforeRet_;
							}
							LA153_: ;
							i_9 += ((NI) 1);
						} LA149: ;
					}
				}
				result = NIM_TRUE;
			}
			LA145_: ;
		}
		break;
		}
	}
	goto LA1_;
	LA71_: ;
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, matchRange__patterns_437)(tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI i) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		NI j;
		NI colontmp_;
		NI i_2;
		j = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(p);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				j = i_2;
				{
					NIM_BOOL T6_;
					T6_ = (NIM_BOOL)0;
					T6_ = matches__patterns_29(c, (*p)._kind_6.sons->data[j], (*n)._kind_6.sons->data[(NI)(i + j)]);
					if (!!(T6_)) goto LA7_;
					unsureAsgnRef((void**) (&(*c).mapping), NIM_NIL);
					(*c).mappingIsFull = NIM_FALSE;
					result = NIM_FALSE;
					goto BeforeRet_;
				}
				LA7_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = NIM_TRUE;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, matchStmtList__patterns_432)(tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T7_;
		NI T8_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n_2;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*p).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115));
		if (!(T4_)) goto LA5_;
		T4_ = ((*n).kind == (*p).kind);
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T7_ = (NI)0;
		T7_ = len__ast_3155(p);
		T8_ = (NI)0;
		T8_ = len__ast_3155(n);
		T3_ = (T7_ < T8_);
		LA6_: ;
		if (!T3_) goto LA9_;
		n_2 = flattenStmts__trees_355(n);
		{
			NI i;
			NI colontmp_;
			NI T12_;
			NI T13_;
			NI res;
			i = (NI)0;
			colontmp_ = (NI)0;
			T12_ = (NI)0;
			T12_ = len__ast_3155(n_2);
			T13_ = (NI)0;
			T13_ = len__ast_3155(p);
			colontmp_ = (NI)(T12_ - T13_);
			res = ((NI) 0);
			{
				while (1) {
					if (!(res <= colontmp_)) goto LA15;
					i = res;
					{
						NIM_BOOL T18_;
						NI T21_;
						NI T22_;
						NI T23_;
						T18_ = (NIM_BOOL)0;
						T18_ = matchRange__patterns_437(c, p, n_2, i);
						if (!T18_) goto LA19_;
						(*c).subMatch = NIM_TRUE;
						result = newNodeI__ast_3324(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115), (*n_2).info, ((NI) 3));
						asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), extractRange__trees_362(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115), n_2, ((NI) 0), (NI)(i - ((NI) 1))));
						T21_ = (NI)0;
						T21_ = len__ast_3155(p);
						asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), extractRange__trees_362(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115), n_2, i, (NI)((NI)(i + T21_) - ((NI) 1))));
						T22_ = (NI)0;
						T22_ = len__ast_3155(p);
						T23_ = (NI)0;
						T23_ = len__ast_3155(n_2);
						asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 2)]), extractRange__trees_362(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115), n_2, (NI)(i + T22_), (NI)(T23_ - ((NI) 1))));
						goto LA11;
					}
					LA19_: ;
					res += ((NI) 1);
				} LA15: ;
			}
		} LA11: ;
	}
	goto LA1_;
	LA9_: ;
	{
		NIM_BOOL T25_;
		T25_ = (NIM_BOOL)0;
		T25_ = matches__patterns_29(c, p, n);
		if (!T25_) goto LA26_;
		result = n;
	}
	goto LA1_;
	LA26_: ;
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, aliasAnalysisRequested__patterns_495)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* params) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__ast_3155(params);
		if (!(((NI) 2) <= T3_)) goto LA4_;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(params);
			i_2 = ((NI) 1);
			{
				while (1) {
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* param;
					if (!(i_2 < colontmp_)) goto LA8;
					i = i_2;
					param = (*(*params)._kind_6.sons->data[i])._kind_4.sym;
					{
						tyEnum_TAliasRequest__7zQvSP68l08u9cyWRw1zgvg T11_;
						T11_ = (tyEnum_TAliasRequest__7zQvSP68l08u9cyWRw1zgvg)0;
						T11_ = whichAlias__parampatterns_48(param);
						if (!!((T11_ == ((tyEnum_TAliasRequest__7zQvSP68l08u9cyWRw1zgvg) 1)))) goto LA12_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA12_: ;
					i_2 += ((NI) 1);
				} LA8: ;
			}
		}
	}
	LA4_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addToArgList__patterns_516)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = !(((*(*n).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 7)));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			if (!!(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152)))) goto LA9_;
			add__ast_4798(result, n);
		}
		goto LA7_;
		LA9_: ;
		{
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_3155(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA14;
						i = i_2;
						add__ast_4798(result, (*n)._kind_6.sons->data[i]);
						i_2 += ((NI) 1);
					} LA14: ;
				}
			}
		}
		LA7_: ;
	}
	LA5_: ;
}
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__ast_3155(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, applyRule__patterns_548)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA ctx;
	NI T1_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* m;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T6_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* params;
	NIM_BOOL requiresAA;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* args;
{	result = NIM_NIL;
	nimZeroMem((void*)(&ctx), sizeof(tyObject_TPatternContext__bDsjsp03bzs814RT25hYsA));
	ctx.owner = s;
	ctx.c = c;
	T1_ = (NI)0;
	T1_ = len__ast_3990((*s).typ);
	ctx.formals = (NI)(T1_ - ((NI) 1));
	m = matchStmtList__patterns_432((&ctx), (*(*s).ast)._kind_6.sons->data[((NI) 1)], n);
	{
		if (!(m == 0)) goto LA4_;
		result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
		goto BeforeRet_;
	}
	LA4_: ;
	result = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27), (*n).info);
	T6_ = NIM_NIL;
	T6_ = newSymNode__ast_3707(s, (*n).info);
	add__ast_4798(result, T6_);
	params = (*(*s).typ).n;
	requiresAA = aliasAnalysisRequested__patterns_495(params);
	args = NIM_NIL;
	{
		if (!requiresAA) goto LA9_;
		args = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152), (*n).info);
	}
	LA9_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(params);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* param;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x;
				if (!(i_2 < colontmp_)) goto LA13;
				i = i_2;
				param = (*(*params)._kind_6.sons->data[i])._kind_4.sym;
				x = getLazy__patterns_17((&ctx), param);
				{
					if (!(x == 0)) goto LA16_;
					result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
					goto BeforeRet_;
				}
				LA16_: ;
				add__ast_4798(result, x);
				{
					if (!requiresAA) goto LA20_;
					addToArgList__patterns_516(args, x);
				}
				LA20_: ;
				i_2 += ((NI) 1);
			} LA13: ;
		}
	}
	{
		if (!requiresAA) goto LA24_;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3155(params);
			i_4 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* rs;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* param_2;
					tyEnum_TAliasRequest__7zQvSP68l08u9cyWRw1zgvg T29_;
					if (!(i_4 < colontmp__2)) goto LA28;
					i_3 = i_4;
					rs = (*result)._kind_6.sons->data[i_3];
					param_2 = (*(*params)._kind_6.sons->data[i_3])._kind_4.sym;
					T29_ = (tyEnum_TAliasRequest__7zQvSP68l08u9cyWRw1zgvg)0;
					T29_ = whichAlias__parampatterns_48(param_2);
					switch (T29_) {
					case ((tyEnum_TAliasRequest__7zQvSP68l08u9cyWRw1zgvg) 1):
					{
					}
					break;
					case ((tyEnum_TAliasRequest__7zQvSP68l08u9cyWRw1zgvg) 2):
					{
						NIM_BOOL ok;
						ok = NIM_FALSE;
						{
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg;
							arg = NIM_NIL;
							{
								NI i_5;
								NI colontmp__3;
								NI i_6;
								i_5 = (NI)0;
								colontmp__3 = (NI)0;
								colontmp__3 = safeLen__ast_3148(args);
								i_6 = ((NI) 0);
								{
									while (1) {
										if (!(i_6 < colontmp__3)) goto LA35;
										i_5 = i_6;
										arg = (*args)._kind_6.sons->data[i_5];
										{
											NIM_BOOL T38_;
											tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA T40_;
											T38_ = (NIM_BOOL)0;
											T38_ = !((arg == rs));
											if (!(T38_)) goto LA39_;
											T40_ = (tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA)0;
											T40_ = isPartOf__aliases_129(rs, arg);
											T38_ = (T40_ == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 2));
											LA39_: ;
											if (!T38_) goto LA41_;
											ok = NIM_TRUE;
											goto LA32;
										}
										LA41_: ;
										i_6 += ((NI) 1);
									} LA35: ;
								}
							}
						} LA32: ;
						{
							if (!!(ok)) goto LA45_;
							result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
							goto BeforeRet_;
						}
						LA45_: ;
					}
					break;
					case ((tyEnum_TAliasRequest__7zQvSP68l08u9cyWRw1zgvg) 3):
					{
						NIM_BOOL ok_2;
						ok_2 = NIM_TRUE;
						{
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg_2;
							arg_2 = NIM_NIL;
							{
								NI i_7;
								NI colontmp__4;
								NI i_8;
								i_7 = (NI)0;
								colontmp__4 = (NI)0;
								colontmp__4 = safeLen__ast_3148(args);
								i_8 = ((NI) 0);
								{
									while (1) {
										if (!(i_8 < colontmp__4)) goto LA51;
										i_7 = i_8;
										arg_2 = (*args)._kind_6.sons->data[i_7];
										{
											NIM_BOOL T54_;
											tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA T56_;
											T54_ = (NIM_BOOL)0;
											T54_ = !((arg_2 == rs));
											if (!(T54_)) goto LA55_;
											T56_ = (tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA)0;
											T56_ = isPartOf__aliases_129(rs, arg_2);
											T54_ = !((T56_ == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 0)));
											LA55_: ;
											if (!T54_) goto LA57_;
											ok_2 = NIM_FALSE;
											goto LA48;
										}
										LA57_: ;
										i_8 += ((NI) 1);
									} LA51: ;
								}
							}
						} LA48: ;
						{
							if (!!(ok_2)) goto LA61_;
							result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
							goto BeforeRet_;
						}
						LA61_: ;
					}
					break;
					}
					i_4 += ((NI) 1);
				} LA28: ;
			}
		}
	}
	LA24_: ;
	markUsed__sigmatch_85(c, (*n).info, s);
	{
		if (!ctx.subMatch) goto LA65_;
		asgnRef((void**) (&(*m)._kind_6.sons->data[((NI) 1)]), result);
		result = m;
	}
	LA65_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, atmpatternsdotnim_DatInit000)(void) {
static TNimNode* TM__boskDBJ4Cp44KknuaESeng_6_2[2];
static TNimNode TM__boskDBJ4Cp44KknuaESeng_0[3];
NTIobject__ZMveiFLFjcEa9b3tNmF1suw_.size = sizeof(tyObject_Env_patternsdotnim_matchNested___ZMveiFLFjcEa9b3tNmF1suw);
NTIobject__ZMveiFLFjcEa9b3tNmF1suw_.align = NIM_ALIGNOF(tyObject_Env_patternsdotnim_matchNested___ZMveiFLFjcEa9b3tNmF1suw);
NTIobject__ZMveiFLFjcEa9b3tNmF1suw_.kind = 17;
NTIobject__ZMveiFLFjcEa9b3tNmF1suw_.base = (&NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_);
TM__boskDBJ4Cp44KknuaESeng_6_2[0] = &TM__boskDBJ4Cp44KknuaESeng_0[1];
TM__boskDBJ4Cp44KknuaESeng_0[1].kind = 1;
TM__boskDBJ4Cp44KknuaESeng_0[1].offset = offsetof(tyObject_Env_patternsdotnim_matchNested___ZMveiFLFjcEa9b3tNmF1suw, colonstate_);
TM__boskDBJ4Cp44KknuaESeng_0[1].typ = (&NTIint__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__boskDBJ4Cp44KknuaESeng_0[1].name = ":state";
TM__boskDBJ4Cp44KknuaESeng_6_2[1] = &TM__boskDBJ4Cp44KknuaESeng_0[2];
TM__boskDBJ4Cp44KknuaESeng_0[2].kind = 1;
TM__boskDBJ4Cp44KknuaESeng_0[2].offset = offsetof(tyObject_Env_patternsdotnim_matchNested___ZMveiFLFjcEa9b3tNmF1suw, p1);
TM__boskDBJ4Cp44KknuaESeng_0[2].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__boskDBJ4Cp44KknuaESeng_0[2].name = "p1";
TM__boskDBJ4Cp44KknuaESeng_0[0].len = 2; TM__boskDBJ4Cp44KknuaESeng_0[0].kind = 2; TM__boskDBJ4Cp44KknuaESeng_0[0].sons = &TM__boskDBJ4Cp44KknuaESeng_6_2[0];
NTIobject__ZMveiFLFjcEa9b3tNmF1suw_.node = &TM__boskDBJ4Cp44KknuaESeng_0[0];
NTIrefobject__9aLIDkd3W4BIOb9auvDSYiog_.size = sizeof(tyObject_Env_patternsdotnim_matchNested___ZMveiFLFjcEa9b3tNmF1suw*);
NTIrefobject__9aLIDkd3W4BIOb9auvDSYiog_.align = NIM_ALIGNOF(tyObject_Env_patternsdotnim_matchNested___ZMveiFLFjcEa9b3tNmF1suw*);
NTIrefobject__9aLIDkd3W4BIOb9auvDSYiog_.kind = 22;
NTIrefobject__9aLIDkd3W4BIOb9auvDSYiog_.base = (&NTIobject__ZMveiFLFjcEa9b3tNmF1suw_);
NTIrefobject__9aLIDkd3W4BIOb9auvDSYiog_.marker = Marker_tyRef__9aLIDkd3W4BIOb9auvDSYiog;
}

